aboutsummaryrefslogtreecommitdiff
path: root/engines/mads/scene_data.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/mads/scene_data.h')
-rw-r--r--engines/mads/scene_data.h35
1 files changed, 25 insertions, 10 deletions
diff --git a/engines/mads/scene_data.h b/engines/mads/scene_data.h
index d59d746706..9b1825f4b7 100644
--- a/engines/mads/scene_data.h
+++ b/engines/mads/scene_data.h
@@ -125,7 +125,7 @@ struct ARTHeader {
Common::Array<RGB6> _palette;
Common::Array<PaletteCycle> _paletteCycles;
- void load(Common::SeekableReadStream *f);
+ void load(Common::SeekableReadStream *f, bool isV2);
};
/**
@@ -177,23 +177,38 @@ public:
static SceneInfo *init(MADSEngine *vm);
/**
- loads the data
+ * loads the data
*/
void load(int sceneId, int variant, const Common::String &resName, int flags,
MSurface &depthSurface, MSurface &bgSurface);
/**
- * Loads the given surface with depth information of a given scene
- * @param depthSurface Depth/walk surface
- * @param variant Variant number to load
- */
+ * Loads the palette for a scene
+ */
+ void loadPalette(int sceneId, int artFileNum, const Common::String &resName, int flags, MSurface &bgSurface);
+
+ /**
+ * Loads a V1 game background
+ */
+ void loadMadsV1Background(int sceneId, const Common::String &resName, int flags, MSurface &bgSurface);
+
+ /**
+ * Loads a V2 game background
+ */
+ void loadMadsV2Background(int sceneId, const Common::String &resName, int flags, MSurface &bgSurface);
+
+ /**
+ * Loads the given surface with depth information of a given scene
+ * @param depthSurface Depth/walk surface
+ * @param variant Variant number to load
+ */
virtual void loadCodes(MSurface &depthSurface, int variant) = 0;
/**
- * Loads the given surface with depth information of a given scene
- * @param depthSurface Depth/walk surface
- * @param stream Stream to load the data from
- */
+ * Loads the given surface with depth information of a given scene
+ * @param depthSurface Depth/walk surface
+ * @param stream Stream to load the data from
+ */
virtual void loadCodes(MSurface &depthSurface, Common::SeekableReadStream *stream) = 0;
};